@@ -6,11 +6,11 @@ Rubric::WebApp::URI - URIs for Rubric web requests
 
 =head1 VERSION
 
- $Id: URI.pm,v 1.2 2004/11/25 03:29:26 rjbs Exp $
+ $Id: URI.pm,v 1.3 2004/11/25 05:58:54 rjbs Exp $
 
 =head1 DESCRIPTION
 
-This module provides methods for generating the URLs for Rubric requests.
+This module provides methods for generating the URIs for Rubric requests.
 
 =cut
 
@@ -23,29 +23,42 @@ use Rubric::Config;
 
 =head2 root
 
+the URI for the root of the Rubric; taken from uri_root in config
+
 =cut
 
-sub root { Rubric::Config->url_root }
+sub root { Rubric::Config->uri_root }
 	
 =head2 stylesheet
 
+the URI for the stylesheet; taken from css_href in config
+
 =cut
 
 sub stylesheet { Rubric::Config->css_href; }
 
 =head2 logout
 
+URI to log out
+
 =cut
 
-sub logout { Rubric::Config->url_root . '/logout' }
+sub logout { Rubric::Config->uri_root . '/logout' }
 
 =head2 login
 
+URI to form for log in
+
 =cut
 
-sub login { Rubric::Config->url_root . '/login' }
+sub login { Rubric::Config->uri_root . '/login' }
 
-=head2 entries
+=head2 entries(\%arg)
+
+URI for entry listing; valid keys for C<%arg>:
+
+ user - entries for one user
+ tags - arrayref of tag names
 
 =cut
 
@@ -53,15 +66,17 @@ sub entries {
 	my ($class, $arg) = @_;
 	$arg->{tags} ||= [];
 
-	my $url = $class->root;
-	$url .=   $arg->{user}  ? "/user/$arg->{user}"
+	my $uri = $class->root;
+	$uri .=   $arg->{user}  ? "/user/$arg->{user}"
 	      : @{$arg->{tags}} ? "/tag"
 	      : '';
-	$url .= ('/' . join('+', @{$arg->{tags}}) . '/') if @{$arg->{tags}};
-	return $url;
+	$uri .= ('/' . join('+', @{$arg->{tags}}) . '/') if @{$arg->{tags}};
+	return $uri;
 }
 
-=head2 entry
+=head2 entry($entry)
+
+URI to view entry
 
 =cut
 
@@ -69,11 +84,13 @@ sub entry {
 	my ($class, $entry) = @_;
 	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
 
-	return Rubric::Config->url_root . "/entry/" . $entry->id;
+	return Rubric::Config->uri_root . "/entry/" . $entry->id;
 }
 
 
-=head2 edit_entry
+=head2 edit_entry($entry)
+
+URI to edit entry
 
 =cut
 
@@ -81,10 +98,12 @@ sub edit_entry {
 	my ($class, $entry) = @_;
 	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
 
-	return Rubric::Config->url_root . "/edit/" . $entry->id;
+	return Rubric::Config->uri_root . "/edit/" . $entry->id;
 }
 
-=head2 delete_entry
+=head2 delete_entry($entry)
+
+URI to delete entry
 
 =cut
 
@@ -92,14 +111,16 @@ sub delete_entry {
 	my ($class, $entry) = @_;
 	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
 
-	return Rubric::Config->url_root . "/delete/" . $entry->id;
+	return Rubric::Config->uri_root . "/delete/" . $entry->id;
 }
 
 =head2 post_entry
 
+URI for new entry form
+
 =cut
 
-sub post_entry { Rubric::Config->url_root . "/post"; }
+sub post_entry { Rubric::Config->uri_root . "/post"; }
 
 =head1 TODO
 
